==> haskell-hspec-meta-2.10.5-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-meta
version:              2.10.5
visibility:           public
id:                   hspec-meta-2.10.5-EKM6JVeTDXTBD6qFlnkGgP
key:                  hspec-meta-2.10.5-EKM6JVeTDXTBD6qFlnkGgP
license:              MIT
copyright:
    (c) 2011-2022 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.

category:             Testing
abi:                  d7d3c3c2d91441d6271526ec479cfae7
exposed:              True
exposed-modules:      Test.Hspec.Discover Test.Hspec.Meta
hidden-modules:
    Test.Hspec Test.Hspec.Formatters Test.Hspec.QuickCheck
    Test.Hspec.Runner GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
    Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Types
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
    Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
    Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
    Control.Concurrent.Async Data.Algorithm.Diff Test.HUnit
    Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal Test.HUnit.Text
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
    Test.Hspec.Expectations.Matcher Paths_hspec_meta

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-meta-2.10.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-meta-2.10.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-meta
hs-libraries:         HShspec-meta-2.10.5-EKM6JVeTDXTBD6qFlnkGgP
depends:
    QuickCheck-2.14.3-5Q3LTiKAdB0LFKfPwDt7Ga
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE array-0.5.4.0
    base-4.16.4.0 call-stack-0.4.0-kYtciisYfe7TdjBJDTvHP
    clock-0.8.4-Kzh7X2kPtrQ91MTkkNH1hr deepseq-1.4.6.1
    directory-1.3.6.2 filepath-1.4.2.2 ghc-9.2.8 ghc-boot-th-9.2.8
    quickcheck-io-0.2.0-EjCXA1fO1A96kJXrvvPYxB
    random-1.2.1.2-3aSfWlsu7xc3wK3TRJn2vY
    setenv-0.1.1.3-3TgCzb5FKNIC6AFHCaPUY stm-2.5.0.2 time-1.11.1.1
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html:         /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-meta-2.10.5-200-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-meta
version:              2.10.5
visibility:           public
id:                   hspec-meta-2.10.5-IfLQMqROdZaD61yUCk0K8j
key:                  hspec-meta-2.10.5-IfLQMqROdZaD61yUCk0K8j
license:              MIT
copyright:
    (c) 2011-2022 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.

category:             Testing
abi:                  2ce04c871ab2c3cb65ea15dad9b85c7f
exposed:              True
exposed-modules:      Test.Hspec.Discover Test.Hspec.Meta
hidden-modules:
    Test.Hspec Test.Hspec.Formatters Test.Hspec.QuickCheck
    Test.Hspec.Runner GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
    Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Types
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
    Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
    Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
    Control.Concurrent.Async Data.Algorithm.Diff Test.HUnit
    Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal Test.HUnit.Text
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
    Test.Hspec.Expectations.Matcher Paths_hspec_meta

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-meta-2.10.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-meta
hs-libraries:         HShspec-meta-2.10.5-IfLQMqROdZaD61yUCk0K8j
depends:
    QuickCheck-2.14.3-JggVBRSlKYhHS3I1VorUGb
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-Gks8vDlHlGUGqRIGcZADk4
    clock-0.8.4-G8wlPXZYYku2UL1xevtvNT deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8 ghc-boot-th-9.4.8
    quickcheck-io-0.2.0-GAl7hIAjToHK7HrAwAdweM
    random-1.2.1.2-J6mYBSGGDLVAHQqGKIioSR
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb stm-2.5.1.0 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html:         /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
